@@ -254,10 +254,13 @@ class baseWebBrowserController:
         if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
 
             # WebDriver終了処理
-            self.browserCtl.wDriver.stop_client()
-            self.browserCtl.wDriver.close()
-            self.browserCtl.wDriver.quit()
-
+            try:
+                self.browserCtl.wDriver.stop_client()
+                self.browserCtl.wDriver.close()
+                self.browserCtl.wDriver.quit()
+            except Exception as e:
+                Logger.logging.warning(str(e))
+                
             # WebDriver終了処理-ログ出力
             Logger.logging.info('WebDriver-Quit.')
             
