@@ -54,6 +54,17 @@ class browserContainer:
             
             # 基底側コンストラクタ呼び出し
             super().__init__(_config)
+
+        def __del__(self):
+            
+            """
+            デストラクタ
+            """
+            
+            # webdriver - quit
+            self.wDriver.quit()
+            # ログ出力
+            Logger.logging.info('chrome webdriver is quit.')
             
         def getWebDriver(self):
             
@@ -107,7 +118,19 @@ class browserContainer:
             
             # 基底側コンストラクタ呼び出し
             super().__init__(_config)
+        
+        def __del__(self):
             
+            """
+            デストラクタ
+            """
+            
+            # webdriver - quit
+            self.wDriver.close()
+            self.wDriver.quit()
+            # ログ出力
+            Logger.logging.info('firefox webdriver is quit.')
+
         def getWebDriver(self):
             
             """ 
